-----------------------------------------
What we'll cover here
-----------------------------------------

This introduction will allow you to use Elephantoplasty in your projects.
It doesn't assume you've done any SQL before.



